- `Programming recommendation in PEP8 <https://peps.python.org/pep-0008/#programming-recommendations>`_
- `PEP 760 – No More Bare Excepts (Rejected) <https://peps.python.org/pep-0760/>`_
- `Discussion about PEP 760 <https://discuss.python.org/t/pep-760-no-more-bare-excepts/67182>`_
